var NAVTREEINDEX18 =
{
"iso8859__5_8h_source.html":[7,0,1,0,1,22],
"iso8859__6_8h_source.html":[7,0,1,0,1,23],
"iso8859__7_8h_source.html":[7,0,1,0,1,24],
"iso8859__8_8h_source.html":[7,0,1,0,1,25],
"iso8859__9_8h_source.html":[7,0,1,0,1,26],
"iso8859__9e_8h_source.html":[7,0,1,0,1,27],
"jisx0201_8h_source.html":[7,0,1,0,1,28],
"jisx0208_8h_source.html":[7,0,1,0,1,29],
"jisx0212_8h_source.html":[7,0,1,0,1,30],
"koi8__c_8h_source.html":[7,0,1,0,1,31],
"koi8__r_8h_source.html":[7,0,1,0,1,32],
"koi8__u_8h_source.html":[7,0,1,0,1,33],
"ksc5601_8h_source.html":[7,0,1,0,1,34],
"license.html":[0,19],
"mac_8H.html":[7,0,0,155],
"mac_8H_source.html":[7,0,0,155],
"math_8h_source.html":[7,0,0,156],
"mediumarrow_8h_source.html":[7,0,1,38],
"migration_1_4.html":[0,18],
"migration_1_4.html#migration_1_4_copy_image":[0,18,4],
"migration_1_4.html#migration_1_4_fl_override":[0,18,3],
"migration_1_4.html#migration_1_4_headers":[0,18,0],
"migration_1_4.html#migration_1_4_modern_cmake":[0,18,6],
"migration_1_4.html#migration_1_4_preferences":[0,18,1],
"migration_1_4.html#migration_1_4_timeout":[0,18,2],
"migration_1_4.html#migration_1_4_windows_font":[0,18,7],
"migration_1_4.html#migration_1_4_x11_compat":[0,18,5],
"mk__wcwidth_8c_source.html":[7,0,1,0,3],
"mulelao_8h_source.html":[7,0,1,0,1,35],
"names_8h.html":[7,0,0,157],
"names_8h_source.html":[7,0,0,157],
"numericsort_8c.html":[7,0,1,39],
"numericsort_8c.html#a0b2d01d871793cb319e486f89a6d1c3e":[7,0,1,39,0],
"numericsort_8c.html#a8a624f01e44b5462d6eca0567fb9c641":[7,0,1,39,1],
"opengl.html":[0,10],
"opengl.html#opengl3":[0,10,8],
"opengl.html#opengl_defining":[0,10,1,0],
"opengl.html#opengl_draw":[0,10,1,1],
"opengl.html#opengl_drawing":[0,10,5],
"opengl.html#opengl_handle":[0,10,1,2],
"opengl.html#opengl_highdpi":[0,10,2],
"opengl.html#opengl_normal":[0,10,3],
"opengl.html#opengl_optimizer":[0,10,7],
"opengl.html#opengl_speed":[0,10,6],
"opengl.html#opengl_subclass":[0,10,1],
"opengl.html#opengl_using":[0,10,0],
"opengl.html#opengl_with_fltk_widgets":[0,10,4],
"osissues.html":[0,17],
"osissues.html#double_window":[0,17,4,4],
"osissues.html#non_ascii_filenames":[0,17,3,0],
"osissues.html#osissues_accessing":[0,17,0],
"osissues.html#osissues_drawing_xlib":[0,17,2,1],
"osissues.html#osissues_icon_osx":[0,17,4,0],
"osissues.html#osissues_icon_windows":[0,17,3,6],
"osissues.html#osissues_localize":[0,17,4,2],
"osissues.html#osissues_mac_files":[0,17,4,5],
"osissues.html#osissues_macos":[0,17,4],
"osissues.html#osissues_msdos_console":[0,17,3,7],
"osissues.html#osissues_quartz":[0,17,4,1],
"osissues.html#osissues_retina":[0,17,4,3],
"osissues.html#osissues_specialx":[0,17,2,3],
"osissues.html#osissues_unix":[0,17,2],
"osissues.html#osissues_wayland":[0,17,5],
"osissues.html#osissues_wayland_decoration":[0,17,5,2],
"osissues.html#osissues_wayland_scaling":[0,17,5,0],
"osissues.html#osissues_wayland_window_icon":[0,17,5,1],
"osissues.html#osissues_win32":[0,17,3],
"osissues.html#osissues_win32_gdi":[0,17,3,3],
"osissues.html#osissues_win32_messages":[0,17,3,2],
"osissues.html#osissues_win32_problems":[0,17,3,8],
"osissues.html#osissues_windows_highdpi":[0,17,3,4],
"osissues.html#osissues_windows_scaling":[0,17,3,5],
"osissues.html#osissues_wl_x11_hybrid":[0,17,1],
"osissues.html#osissues_wm_quit":[0,17,3,1],
"osissues.html#osissues_x_events":[0,17,2,0],
"osissues.html#osissues_x_icon":[0,17,2,4],
"osissues.html#osissues_x_scaling":[0,17,2,6],
"osissues.html#osissues_xresources":[0,17,2,5],
"osissues.html#osissues_xvisual":[0,17,2,2],
"pages.html":[],
"platform_8H_source.html":[7,0,0,158],
"platform__types_8h.html":[7,0,0,159],
"platform__types_8h.html#a25fe41b1bd340d52f7970051d8b680bc":[7,0,0,159,1],
"platform__types_8h.html#a5c7c4e4558d665307552718e828d28d8":[7,0,0,159,3],
"platform__types_8h.html#a5d4011c75b1fe25d9ef36e8ae9e2995c":[7,0,0,159,0],
"platform__types_8h.html#aa488d0a3bed15e82539fcf42384eb153":[7,0,0,159,8],
"platform__types_8h.html#abe7c95701dd7f8d2a112aff7e0ff5345":[7,0,0,159,6],
"platform__types_8h.html#ac8e78a1cbd640e700961c06785b83409":[7,0,0,159,7],
"platform__types_8h.html#adb631ddcd69e049ecd3ce0df56624bbb":[7,0,0,159,4],
"platform__types_8h.html#af2b4daf25dc744e8cea191ee827ce767":[7,0,0,159,5],
"platform__types_8h.html#afea081b5e7799663f2634b3bfba67409":[7,0,0,159,2],
"platform__types_8h_source.html":[7,0,0,159],
"preface.html":[0,0],
"preface.html#preface_abbreviations":[0,0,2],
"preface.html#preface_conventions":[0,0,1],
"preface.html#preface_copyrights":[0,0,3],
"preface.html#preface_organisation":[0,0,0],
"print__button_8h_source.html":[7,0,1,40],
"print__panel_8h_source.html":[7,0,1,41],
"resize.html":[0,5],
"resize.html#resize_complex":[0,5,2],
"resize.html#resize_disabled":[0,5,0],
"resize.html#resize_practical":[0,5,3],
"resize.html#resize_simple":[0,5,1],
"slowarrow_8h_source.html":[7,0,1,42],
"spacing_8h_source.html":[7,0,1,0,0,2],
"structFL__CHART__ENTRY.html":[6,0,13],
"structFL__CHART__ENTRY.html#a438fb16944c3b01425c92aeaffd79445":[6,0,13,2],
"structFL__CHART__ENTRY.html#ac87a71bfa4f7beb321a7b0ada94f3b61":[6,0,13,1],
"structFL__CHART__ENTRY.html#af941749495bafe426c2187e0f7eb8d8c":[6,0,13,0],
"structFl__GIF__Image_1_1GIF__FRAME.html":[6,0,40,0],
"structFl__GIF__Image_1_1GIF__FRAME_1_1CPAL.html":[6,0,40,0,0],
"structFl__Glut__Bitmap__Font.html":[6,0,43],
"structFl__Glut__StrokeChar.html":[6,0,44],
"structFl__Glut__StrokeFont.html":[6,0,45],
"structFl__Glut__StrokeStrip.html":[6,0,46],
"structFl__Glut__StrokeVertex.html":[6,0,47],
"structFl__Help__Block.html":[6,0,51],
"structFl__Help__Font__Stack.html":[6,0,53],
"structFl__Help__Font__Stack.html#a2f654f36e75490b0bcdd71c1eddd20ea":[6,0,53,2],
"structFl__Help__Font__Stack.html#a316766f09e93398a71fc3bb4731be19c":[6,0,53,6],
"structFl__Help__Font__Stack.html#a3e595bc9d80ba29e1f10d9dfab8435e3":[6,0,53,4],
"structFl__Help__Font__Stack.html#a7d53bd14a9f5459d3b82f19351fbd347":[6,0,53,0],
"structFl__Help__Font__Stack.html#a99bd3c48ee5b70dd6aed6507d144e2ec":[6,0,53,5],
"structFl__Help__Font__Stack.html#adca714aadcd0ba701747e4c26ee8ff90":[6,0,53,1],
"structFl__Help__Font__Stack.html#af931d5b3f964f60604fa418445b1fffb":[6,0,53,3],
"structFl__Help__Font__Style.html":[6,0,54],
"structFl__Help__Font__Style.html#a6669f9feb7222711efae1aed788ecd48":[6,0,54,4],
"structFl__Help__Font__Style.html#ac29024680aed077d72c7c81f35e92d67":[6,0,54,2],
"structFl__Help__Font__Style.html#adab2af66a1ea3ff906b23b3fb1523798":[6,0,54,1],
"structFl__Help__Font__Style.html#ae899084db9ae30a5de3bb35e179f594a":[6,0,54,3],
"structFl__Help__Font__Style.html#afb3d4ee42661c62d84196e746526e239":[6,0,54,0],
"structFl__Help__Link.html":[6,0,55],
"structFl__Help__Link.html#a0ccda15c03d1015cb2846c66d65213c8":[6,0,55,2],
"structFl__Help__Link.html#ab162e790bea66ffc898f000fdc1e20d2":[6,0,55,1],
"structFl__Help__Link.html#ab7a1011018b6604e32ce62618fd60f9d":[6,0,55,0],
"structFl__Help__Link.html#ab9e2ffc56e2357b281229a4e93828339":[6,0,55,3],
"structFl__Help__Link.html#ad77f7b9105f689fe2fb5847d5b7e8ae5":[6,0,55,5],
"structFl__Help__Link.html#ae4779c7f0291c60fdeb00eb088133fe2":[6,0,55,4],
"structFl__Help__Target.html":[6,0,56],
"structFl__Help__Target.html#af278961a4d3d04fab6e52c2ea623bd1e":[6,0,56,0],
"structFl__Help__Target.html#af7bb97b0dfc3e302d1a4afa7408d0d99":[6,0,56,1],
"structFl__ICO__Image_1_1IconDirEntry.html":[6,0,63,0],
"structFl__ICO__Image_1_1IconDirEntry.html#a17477d91ada7784b2acedd110d541fa2":[6,0,63,0,1],
"structFl__ICO__Image_1_1IconDirEntry.html#a1952a6d987ce164e57cb9de0fafaf1c6":[6,0,63,0,6],
"structFl__ICO__Image_1_1IconDirEntry.html#a4a6c079bcb582a31c40d661f5bbba053":[6,0,63,0,3],
"structFl__ICO__Image_1_1IconDirEntry.html#a4d428ae5be4664aec326c00ba7af2626":[6,0,63,0,7],
"structFl__ICO__Image_1_1IconDirEntry.html#a6e00fb9b27baa402d977d34ea25b0181":[6,0,63,0,5],
"structFl__ICO__Image_1_1IconDirEntry.html#abcfcf40672affb649a58cec771535dd0":[6,0,63,0,4],
"structFl__ICO__Image_1_1IconDirEntry.html#ad31a07fd901f89cc9bbfa6177acfb928":[6,0,63,0,2],
"structFl__ICO__Image_1_1IconDirEntry.html#ad5b442db4ce4355c9b5e8371b53cca9a":[6,0,63,0,0],
"structFl__Label.html":[6,0,72],
"structFl__Label.html#a0a3c4875555bcdb2f83e495dddb26349":[6,0,72,0],
"structFl__Label.html#a26d6e87dbf601f7a38d4c0f391b48558":[6,0,72,10],
"structFl__Label.html#a2bff314c295248d94c2918a2ca53006d":[6,0,72,4],
"structFl__Label.html#a30b371b7193a9ff17191e330eacfe631":[6,0,72,1],
"structFl__Label.html#a391e859f1c1bafa283b8b04981d1f173":[6,0,72,8],
"structFl__Label.html#a7061f748221b91736fa7cc4dbdaa9adc":[6,0,72,12],
"structFl__Label.html#a7c1c8fefd7dae7e87835c7dfd78c0691":[6,0,72,2],
"structFl__Label.html#aad739e4362e531cd8cc6007ee17af06b":[6,0,72,3],
"structFl__Label.html#ab49f7d8120410b6c48ffd0c563df94c7":[6,0,72,11],
"structFl__Label.html#abb10c5f60afcfa71854e6342f16f3540":[6,0,72,6],
"structFl__Label.html#ac529a96040adfdf459da78492cae92ae":[6,0,72,9],
"structFl__Label.html#ac82178559994ffa5102c35bbb68f7e5b":[6,0,72,7],
"structFl__Label.html#ac9b449b770124edddd9adf10dff12da4":[6,0,72,5],
"structFl__Menu__Item.html":[6,0,79],
"structFl__Menu__Item.html#a026eeb4b0d2aa5b03f9865d9a320edf2":[6,0,79,49],
"structFl__Menu__Item.html#a0824161a9850d4a239b6332ca6cd5125":[6,0,79,61],
"structFl__Menu__Item.html#a08f7f5390965c3eb85d108e738171cfe":[6,0,79,40],
"structFl__Menu__Item.html#a09f06d655f055fbfedf140a40a83b879":[6,0,79,5],
"structFl__Menu__Item.html#a0b46c8823d3d47b430b9ed58c5d57b44":[6,0,79,68],
"structFl__Menu__Item.html#a0c2aa552ddacec2b75b319fe5bc10d3e":[6,0,79,15],
"structFl__Menu__Item.html#a0fb8befc86f43ad3cb339282ec3a9327":[6,0,79,6],
"structFl__Menu__Item.html#a133d1f128a4f0fc0e1332989056e5959":[6,0,79,54],
"structFl__Menu__Item.html#a286bd88b6597d557b6ebec29dea7a942":[6,0,79,65],
"structFl__Menu__Item.html#a2abcdc1355d6b56694c4466e8af96d09":[6,0,79,56],
"structFl__Menu__Item.html#a316cd145a78731841e196b1f227bb4e2":[6,0,79,9],
"structFl__Menu__Item.html#a3aa10c12d3a1d9bd33f90a978ba4c124":[6,0,79,33],
"structFl__Menu__Item.html#a3ab5231b3f7785113ff57210b00f692a":[6,0,79,14],
"structFl__Menu__Item.html#a3d531242e84a7bf8ee27482052f673a5":[6,0,79,16],
"structFl__Menu__Item.html#a4d39aadf722bf13cec46314eb71a404d":[6,0,79,47],
"structFl__Menu__Item.html#a4e60fb0415ecc4521b44f958367955fb":[6,0,79,21],
"structFl__Menu__Item.html#a5622daab819890fd140c72d369816c41":[6,0,79,37],
"structFl__Menu__Item.html#a58f4e8493d449c976bd456b13376f93a":[6,0,79,23],
"structFl__Menu__Item.html#a5a69e6399f9cea8957f13d70ec4cafc5":[6,0,79,59],
"structFl__Menu__Item.html#a63eedfd661b18ebb0f4a65bdfe5aaad7":[6,0,79,11],
"structFl__Menu__Item.html#a68b8f8159f0c4a8e147585c563b3af73":[6,0,79,57],
"structFl__Menu__Item.html#a6983103fb99e1fee59dd705bb2d23147":[6,0,79,28],
"structFl__Menu__Item.html#a6b82c55e9eebbd84c02f023348ed0a54":[6,0,79,1],
"structFl__Menu__Item.html#a6bb4b776fd7d75057b1ab7c473df87ac":[6,0,79,18],
"structFl__Menu__Item.html#a6f9672ace322a67dccf75c33f26c2a52":[6,0,79,20],
"structFl__Menu__Item.html#a7585b85dee7bcde73f202ba4c0585e4e":[6,0,79,58],
"structFl__Menu__Item.html#a75e9aaa761cbc922916329baa734090c":[6,0,79,50],
"structFl__Menu__Item.html#a77ad83a8af95310fa3c153ce4a3f9100":[6,0,79,29],
"structFl__Menu__Item.html#a78eda86db3d602c828478430ddf5c3e5":[6,0,79,7],
"structFl__Menu__Item.html#a7a08d2a710cf449bd8426b7287d983c7":[6,0,79,8],
"structFl__Menu__Item.html#a7b762f887849570b33309537ce2d5fd4":[6,0,79,12],
"structFl__Menu__Item.html#a8094624201d142dc2c9dc376e76f3053":[6,0,79,43],
"structFl__Menu__Item.html#a81cb08f569bfc94f7c98c2481ef945ba":[6,0,79,26],
"structFl__Menu__Item.html#a83e861ad4be4be31ee8bc0f1d2856a5f":[6,0,79,22],
"structFl__Menu__Item.html#a83f59216e6f235c31e1a8a00ec7e34bb":[6,0,79,39],
"structFl__Menu__Item.html#a859fe109e269f057d4b216e5188f5e6e":[6,0,79,63],
"structFl__Menu__Item.html#a9121119645436fd7bd3323e3c6d75a59":[6,0,79,24],
"structFl__Menu__Item.html#a9124b8835da1631ec6dc990ef9ad3ae7":[6,0,79,35],
"structFl__Menu__Item.html#a9839d5dd7ecc444d4593daeca3c3d0a7":[6,0,79,44],
"structFl__Menu__Item.html#a996db6347b53fc0ea8ab6ae763a44a2c":[6,0,79,67],
"structFl__Menu__Item.html#a9ab61f34c774dcb319dc2a1078d79832":[6,0,79,36],
"structFl__Menu__Item.html#a9cde9f1e6208245382224fa48a5e377e":[6,0,79,10],
"structFl__Menu__Item.html#a9dc079ac606be45822ae891733d57642":[6,0,79,34],
"structFl__Menu__Item.html#aa06209e2140c18cb3055bb169f076c13":[6,0,79,52],
"structFl__Menu__Item.html#aa19c02285ba35b06e9ab6e4de014754c":[6,0,79,19],
"structFl__Menu__Item.html#aa4cb1e7f8eaa56b2535218ecde9c1d37":[6,0,79,69],
"structFl__Menu__Item.html#aab7e528aa01116ea9e50eaa2ef012deb":[6,0,79,32],
"structFl__Menu__Item.html#aac2832e9090da6efb3b00fc2435fa738":[6,0,79,17],
"structFl__Menu__Item.html#aae6ba303ffaf74a0267c978ae8ec475f":[6,0,79,62],
"structFl__Menu__Item.html#ac307247c2eab3116a7dac35b7a482617":[6,0,79,51],
"structFl__Menu__Item.html#ac3bef057ccaa73456379b53ce7937978":[6,0,79,45],
"structFl__Menu__Item.html#ac4aadd19ae4889935c5f8a8a3da381d3":[6,0,79,66],
"structFl__Menu__Item.html#ac99b194093ad630fe5e0cab514ffb39a":[6,0,79,31],
"structFl__Menu__Item.html#ac9d5891fb95d8c17654e0dbb7a2ca01e":[6,0,79,4],
"structFl__Menu__Item.html#acdce341881deb78bfac500e0aa42691d":[6,0,79,46],
"structFl__Menu__Item.html#ace9af4322350c383b17f6b1ce868d812":[6,0,79,38],
"structFl__Menu__Item.html#ad82ab3107c63ed28bda8749fe3f14f32":[6,0,79,64],
"structFl__Menu__Item.html#ad9c4c217a240983710154ba912939d39":[6,0,79,53],
"structFl__Menu__Item.html#adab7d2226e5476065dae12fb9457e091":[6,0,79,60],
"structFl__Menu__Item.html#adb1b888c6b17f642f6b7ab52422f3f3f":[6,0,79,0],
"structFl__Menu__Item.html#ade27f92d5a96470c2e212768ead79c00":[6,0,79,13],
"structFl__Menu__Item.html#ae00c6c17473565012940fbc2d40bb877":[6,0,79,30],
"structFl__Menu__Item.html#ae16ecac7723e8534fd74fdcccc9c4f3d":[6,0,79,27],
"structFl__Menu__Item.html#ae779ee458d0e3f8b78e387bc0db9ae40":[6,0,79,48],
"structFl__Menu__Item.html#ae89657ebc69eebd87a0ed10a730ce941":[6,0,79,55],
"structFl__Menu__Item.html#aea24344b71799015e29c4ad5e421e29e":[6,0,79,25],
"structFl__Menu__Item.html#aedb0508adf79fcb6c917b5eacb2601d5":[6,0,79,2],
"structFl__Menu__Item.html#aeedc6f035528f7fd5e3e2397d7112aeb":[6,0,79,41],
"structFl__Menu__Item.html#af4f5dbf86abb2d5158984a05368e923a":[6,0,79,42],
"structFl__Menu__Item.html#af9a1be4dfffcff2ba77cfccfec655588":[6,0,79,3],
"structFl__Multi__Label.html":[6,0,82],
"structFl__Multi__Label.html#a09c69b2d4b971cfb85396795a643f83a":[6,0,82,4],
"structFl__Multi__Label.html#a2fb8179ce00ac149aec20a4f659eb2f8":[6,0,82,3],
"structFl__Multi__Label.html#a50c609957da3af418a48cfea9fbb632a":[6,0,82,1],
"structFl__Multi__Label.html#a6b4edb800cb21d45cd137ecd8a8d66ef":[6,0,82,2],
"structFl__Multi__Label.html#a8a52fb11250265e3132caaa36a24bacf":[6,0,82,5],
"structFl__Multi__Label.html#af72aa419e40c7a64116ea19f4fee4b98":[6,0,82,0],
"structFl__Paged__Device_1_1page__format.html":[6,0,90,0],
"structFl__Paged__Device_1_1page__format.html#a40cbb3d64e0d9b1b94c6f4b430b1a84c":[6,0,90,0,2],
"structFl__Paged__Device_1_1page__format.html#a8f0de961877d6c60870ff7d5e3aae720":[6,0,90,0,0],
"structFl__Paged__Device_1_1page__format.html#ab281b2d2443be0bb9f7fbe59c87346bd":[6,0,90,0,1],
"structFl__Preferences_1_1Entry.html":[6,0,99,0],
"structFl__Scroll_1_1Fl__Region__LRTB.html":[6,0,114,0],
"structFl__Scroll_1_1Fl__Region__LRTB.html#a30c172f8d46c0dd3ef984f8bf3f4bfae":[6,0,114,0,2]
};
